<?php
namespace Retail\Entity;

use Doctrine\ORM\Mapping as ORM;



/**
 * @ORM\Entity
 * @ORM\HasLifecycleCallbacks
 * @ORM\Table(name="retail", uniqueConstraints={@ORM\UniqueConstraint(name="unique_retailer", columns={"name"})})
 */
class Retail
{

	/**
	 * Can archive records.
	 */
	const ARCHIVE = false;
	/**
	 * Pull Synchronization Strategy for this table.
	 */
	const PULL_SYNCH_STRATEGY = false;
	/**
	 * Push Synchronization Strategy for this table.
	 */
	const PUSH_SYNCH_STRATEGY = false;


	/**
	 * @ORM\Id
	 * @ORM\Column(type="integer");
	 * @ORM\GeneratedValue(strategy="AUTO")
	 */
	protected $id;

	/**
	 * @ORM\Column(type="string", length=150, unique=true)
	 */
	protected $name;

	/**
	 * @ORM\Column(type="string", length=64, name="auth_token")
	 */
	protected $authToken;

	/**
	 * @ORM\Column(type="integer");
	 */
	protected $requests = 0;

	/**
	 * @ORM\Column(type="datetime");
	 */
	protected $created;

	/**
	 * @ORM\Column(type="datetime", nullable=true);
	 */
	protected $updated;



	/**
	 * Magic getter to expose protected properties.
	 * @param string $property
	 * @return mixed
	 */
	public function __get($property)
	{
		return $this->$property;
	}

	/**
	 * Magic setter to save protected properties.
	 * @param string $property
	 * @param mixed $value
	 */
	public function __set($property, $value)
	{
		$this->$property = $value;
	}


	/**
	 * @ORM\PrePersist
	 */
	public function setCreateTime()
	{
		$this->created = new \DateTime("now");
	}

	/**
	 * @ORM\PreUpdate
	 */
	public function setUpdateTime()
	{
		$this->updated = new \DateTime("now");
	}

	public function fromArray($data)
	{
		isset($data['name'])
			&& $this->name = $data['name'];
		isset($data['authToken'])
			&& $this->authToken = $data['authToken'];
		isset($data['requests'])
			&& $this->requests = $data['requests'];
	}

	public function toArray()
	{
		return array(
			'id'   => $this->id,
			'name' => $this->name
		);
	}
}
